# Changelog

All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

* Changed project name from OpenAppStack to Stackspin
* Update:
  * Kube-prometheus-stack to helm chart version 22.0.0

## [0.7.0] - 2021-08-19

### Removed

* **BREAKING**: The `oas-secrets` helm chart has been removed (#891)
  Because of this `flux` will remove your existing secrets when you change the
  tracking branch from `v0.6` to `v0.7`.
  Follow our [upgrade guide](https://docs.openappstack.net/en/latest/upgrading.html)
  to prevent data loss!
* Unused flux notification-controller (#840)

### Changed

* Docuementation overhaul (especially for installatation instructions)
* Increase cpu limits for eventrouter (#920)
* Increase mem limits for loki (#910)
* Retry taiko CI test until success
* Enable startupProbe for Nextcloud, remove initialDelaySeconds (#914)
* Reduce loki retention to 8 days because it uses too much disk space
* Update:
  * Taiko to 1.2.6
  * OAS Nextcloud chart to 0.3.2 (Nextcloud app to 20.0)
  * Dockerfile packages
* Pytest now tests cluster resources like deployments, statfulsets for readiness
* Optimize taiko chrome instances for parallel runs (#854)

### Added

* Apps:
  * Wekan 5.41 (chart 5.42)
  * Nextcloud passwords 2021.7.23
  * Nextcloud Calendar 2.3.12
* Wekan, NC passwords and NC calendar to documentation

### Fixed

* Helm chart values overrdides (#873)
* Prometheus CI test (#766)

## [0.6.0] - 2021-07-14

### Added

* Option to use a container image mirror
* .sourceignore file for flux
* Eventrouter to aggregate k8s events in loki
* Fine-tune app resource limits
* Configure outgoing mail for alertmanager
* Code of conduct (CONTRIBUTING.md)
* Contribution docs (CONTRIBUTING.md)
* pre-commit config (.pre-commit-config.yaml)
* Add IP as SAN to k8s cluster API cert
* Add Lets encrypt staging certificate to cert store in test container

### Changed

* Overhaul installation procedure
  * Seperate kubernetes and Openappstack installation
  * Secrets are now only managed on the cluster
  * settings.yml has been replaced with .flux.env and is saved as a secret in
    the cluster
  * Applications can be installed after first install of the cluster
  * Migrate to Flux 2
* Update documentation to reflect new installation procedure and flux2
* Update all helm charts and applications
* Flux 2
  * Increase all pull intervals to 1h
  * Change way of customizing helm charts
* Migrate from behave to taiko for end-to-end tests
* Update k3s and kubernetes version
  * Increase k3s event retention from 1h to 2d
* Loki:
  * Limit storage size
  * Increase chunk size, reduce chunk count
  * Increase retention time
  * Install loki + promtail seperatly, instead of loki-stack
* Use kube-prometheus-stack instead of prometheus + grafana
* Expose alertmanager and prometheus web interface by default
* Increase prometheus retention time
* CI
  * Only install and test apps on changes affecting an app
  * Improve pipeline speed and overall stability
  * Use new disk image template that has haveged pre-installed
  * Update Dockerfile base image to alpine 3.14
  * Test Onlyoffice Nextcloud integration
  * Allow invalid certs for OnlyOffice
  * Use 12GB (=6 cores) for master CI droplet
  * Disable the reuse of VPSs if there is already one

### Removed

* remove old and now unused variables from compatibility-checks role

## [0.5.0] - 2020-09-17

* Added automatic smtp config for nextcloud
* Updated k3s version to 1.18.6+k3s1
  * Updated kubernetes to 1.18.6
* Updated applications:
  * wordpress: 5.4.1
  * nextcloud: 17.0
  * flux: 1.20.2
  * helm-operator: 1.2.0
  * ingress-nginx: 0.35.0
* Use metallb instead of servicelb in order to get ingress source IP and
  allow IP based access controll
* Allow second flux instance for managing additional applications
* Allow k3s kubelet args
* Allow custom extra values for helm charts
* Added advanced installation docs
* Separated ansible playbooks for Kubernetes and OpenAppStack (re-)installation
* Increased installation and general stability

## [0.4.0] - 2020-06-11

* Replaced [local-storage
  provisioner](https://open.greenhost.net/openappstack/local-storage) with
  Rancher's [local-path
  provisioner](https://github.com/rancher/local-path-provisioner)
  * [Patched the
    provisioner](https://github.com/rancher/local-path-provisioner/pull/91) to
    work with Velero. The patched provisioner uses `local` instead of `hostPath`
    Kubernetes volumes
* Replaced RKE with K3s
* Replaced prometheus-operator with Prometheus and Grafana manually installed
* Added loki stack for log viewing
* Added Velero for backups to s3-compatible storage
* Added possibility to not install certain applications
* Updated underlying applications:
  * helm-operator uses Helm 3
  * cert-manager chart 0.15.1
  * local-path-provisioner chart 0.0.13
  * nextcloud chart 0.2.3
    * Nextcloud 17.0.0
    * ONLYOFFICE 5.5.1
      * Fixed: "prepare4shutdown" script is now run before shutdown
  * Rocket.Chat chart 2.0.2
    * [Patched RocketChat version](https://github.com/mrtndwrd/rocket.chat) at
      3.2.2-096aa0023 because of [this ignored
      PR](https://github.com/RocketChat/Rocket.Chat/pull/17377)
  * Wordpress chart 0.1.2
    * Moved repository to open.greenhost.net
    * Updated WordPress to version 5.4.1
    * Removed unused PVC
  * Grafana chart 5.1.4
  * Nginx chart 1.26.1
  * Loki stack chart 0.36.2
  * Prometheus chart 11.4.0

## [0.3.1] - 2020-03-18

* Repair rocket chat installation
* Rocket Chat supports e2e encryption by default
* Upgrade Nextcloud chart version
* Single Sign-on related Jobs are now cleaned up after a successful installation

Known issues:

* Same as 0.3.0

## [0.3.0] - 2020-01-20

* Release candidate for beta tests
* Added features:
  * Single Sign on system at sso.oas.example.org
  * User panel at admin.oas.example.org
  * Rocket.chat version 2.1.1 at chat.oas.yourdomain
  * Use Flux instead of Helmfile to install and update applications
    * Flux version 1.16.0 and helm-operator version 1.0.0-rc4
  * WordPress at www.oas.example.org from [Greenhost's wordpress helm chart](https://code.greenhost.net/open/wordpress-helm)
* Application updates:
  * cert-manager 0.11.0
  * prometheus-operator 0.34.0
  * nginx 0.26.1
  * nextcloud 16.0.1
  * onlyoffice 5.4.1-2
  * rke 0.3.2
  * kubernetes 1.15.5
* Fix many many bugs

Known issues:

* There are some [initial prometheus alerts](https://open.greenhost.net/openappstack/openappstack/issues/286)
  after a fresh OAS installation
* [Prometheus web interface is publicly available](https://open.greenhost.net/openappstack/openappstack/issues/294)
* Single sign-on has some issues:

  * Rocket.chat SSO does not work out of the box (see docs for setup
    instructions)
  * WordPress and Grafana SSO do not give admin permissions to users with the
    "admin" enabled in the user-panel
  * Nextcloud requires email (SMTP) to be set up before you log in with new
    users using SSO

  These issues will be addressed in the next version.

## [0.2.1] - 2019-10-29

This is the release for the second user test.

Fixes:

* [Nextcloud timeout during helmchart install](https://open.greenhost.net/openappstack/openappstack/issues/354)
* [Use prometheus default securitycontext](https://open.greenhost.net/openappstack/openappstack/issues/305)
* [Prometheus installation cannot be repeated](https://open.greenhost.net/openappstack/openappstack/issues/351)
* [Improve test instructions](https://open.greenhost.net/openappstack/openappstack/issues/349)
* [Increase nextcloud livenessprobe's leniency](https://open.greenhost.net/openappstack/openappstack/issues/350)
* [Creating cluster fails if the hostname is oas-dev](https://open.greenhost.net/openappstack/openappstack/issues/346)
* [kube_config_cluster.yml should be copied to local machine earlier](https://open.greenhost.net/openappstack/openappstack/issues/319)

## [0.2.0] - 2019-10-22

* Release candidate for second user test
* Added features:
  * Use onlyoffice image with support for unlimited connections
  * Make local-storage work with subpath mounted PVs
  * Logrotate OAS logs
  * Rewrite and improve OAS installation script
  * Include and update documentation in this repo
  * Allow custom rke config options
  * Update to rke 0.2.7
  * Update k8s to v1.14.3-rancher1-1
  * Update cert-manager to v0.9.1
  * Pin helm to 2.14.3
  * Fix nextcloud issues from user feedback
  * Fix and improve CI tests and pipeline

Known issues:

* There are some [initial prometheus alerts](https://open.greenhost.net/openappstack/openappstack/issues/286)
  after a fresh OAS installation
* [Prometheus web interface is publicly available](https://open.greenhost.net/openappstack/openappstack/issues/294)

## [0.1.0] - 2019-07-31

This is the version for the alpha test.

[Unreleased]: https://open.greenhost.net/openappstack/openappstack/-/compare/0.7.0...master
[0.7.0]: https://open.greenhost.net/openappstack/openappstack/-/compare/0.6.0...0.7.0
[0.6.0]: https://open.greenhost.net/openappstack/openappstack/-/compare/0.5.0...0.6.0
[0.5.0]: https://open.greenhost.net/openappstack/openappstack/-/compare/0.4.0...0.5.0
[0.4.0]: https://open.greenhost.net/openappstack/openappstack/-/compare/0.3.1...0.4.0
[0.3.1]: https://open.greenhost.net/openappstack/openappstack/-/compare/0.3.0...0.3.1
[0.3.0]: https://open.greenhost.net/openappstack/openappstack/-/compare/0.2.1...0.3.0
[0.2.1]: https://open.greenhost.net/openappstack/openappstack/-/compare/0.2.0...0.2.1
[0.2.0]: https://open.greenhost.net/openappstack/openappstack/-/compare/0.1.0...0.2.0
[0.1.0]: https://open.greenhost.net/openappstack/openappstack/-/commits/0.1.0
